@@ -41,7 +41,7 @@ def _sub_operator(model, argument, fieldname):
     if isinstance(argument, dict):
         fieldname = argument['name']
         operator = argument['op']
-        argument = argument['val']
+        argument = argument.get('val')
         relation = None
         if '__' in fieldname:
             fieldname, relation = fieldname.split('__')
@@ -342,7 +342,9 @@ class QueryBuilder(object):
         if numargs == 1:
             return opfunc(field)
         if argument is None:
-            raise TypeError
+            msg = ('To compare a value to NULL, use the is_null/is_not_null '
+                   'operators.')
+            raise TypeError(msg)
         if numargs == 2:
             return opfunc(field, argument)
         return opfunc(field, argument, fieldname)
